/**************************************************************************
 *  Written and Copyright (C) 1999-2001 by Michael J. Gourlay             *
 *               minor distortions by Johannes A. Koeppen                 *
 *               koeppen@ieee.org                                         *
 *                                                                        *
 *  Year(s)     : 2010 - 2015                                             *
 *  File        : globals.h                                               *
 *  Context     : Sdr2 (Not approved for clinical use)                    *
 *  License     : GPL 2 or later                                          *
 *  Description : more or less useful macros                              *
 *                                                                        *
 **************************************************************************/

#ifndef _MACROS_H
#define _MACROS_H


#ifdef _MSC_VER
typedef __int16 int16_t;
typedef unsigned __int16 uint16_t;
typedef __int32 int32_t;
typedef unsigned __int32 uint32_t;
typedef __int64 int64_t;
typedef unsigned __int64 uint64_t;

typedef __int8 CHAR8;
typedef unsigned __int8 UCHAR8;
typedef __int16 INT16;
typedef unsigned __int16 UINT16;
typedef __int32 INT32;
typedef unsigned __int32 UINT32;
#else
#include <stdint.h>
typedef char CHAR8;
typedef unsigned char UCHAR8;
typedef short INT16;
typedef unsigned short UINT16;
typedef int INT32;
typedef unsigned int UINT32;
#endif

#ifdef PI
#undef PI
#endif
#define PI                 3.14159265358979323846264338327950

#define TWO_PI             6.283185307179586476925286766559

#define RAD2DEG            (180.0 / PI)
#define DEG2RAD            (PI / 180.0)

//#define round_uint32_t(x) ((x)>=0?(uint32_t)((x)+0.5):(uint32_t)((x)-0.5))
#define round_int32_t(x) ((x)>=0?(int32_t)((x)+0.5):(int32_t)((x)-0.5))
#define round_int16_t(x) ((x)>=0?(int16_t)((x)+0.5):(int16_t)((x)-0.5))
#define round(x)         ((x)>=0?((x)+0.5):((x)-0.5))


#ifdef SMALL
#undef SMALL
#endif
#define SMALL           1.0e-5 //e-6

#define ABS(x)             (((x)<0)?(-(x)):(x))
#define SIGN(x)            (((x)<0)? (-1) :(1))

#define MAG1(x)            ( (x) < 0 ? (-(x)) : (x) )
#define MAG2(x,y)          (sqrt((x)*(x) + (y)*(y)))
#define MAG3(x,y,z)        (sqrt((x)*(x) + (y)*(y) + (z)*(z)))

#define MIN2(x,y)          (((x)<(y))?(x):(y))
#define MIN3(x,y,z)        MIN2(MIN2((x),(y)),(z))

#define MAX2(x,y)          (((x)>(y))?(x):(y))
#define MAX3(x,y,z)        MAX2(MAX2((x),(y)),(z))

#ifdef MG_NEAR
#undef MG_NEAR
#endif
#define MG_NEAR(x,y) (ABS((x)-(y))<SMALL)

#endif
