/**************************************************************************
 *  Author      : Johannes A. Koeppen, koeppen@ieee.org                   *
 *  Year(s)     : 2010 - 2015                                             *
 *  File        : mainwindow.h                                            *
 *  Context     : Sdr2 (Not approved for clinical use)                    *
 *  License     : GPL 2 or later                                          *
 *  Description : main window, mainly Qt stuff                            *
 *                                                                        *
 **************************************************************************/


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QWidget>
#include <QFileSystemModel>
#include <QModelIndex>
#include <QTreeView>
#include <QtGui/QPushButton>
#include <QApplication>
#include <QClipboard>
#include <QDockWidget>
#include <QCloseEvent>
#include <QtGui/QStatusBar>
#include <QErrorMessage>

#include "qdicomdiriconwidget.h"
#include "miniDcmXmlWidget.h"
#include "miniDcmXmlTree.h"
#include "minDcmImage.h"
#include "qdicomimagewidget.h"
#include "qdicomimageForm.h"
#include "saveVolume.h"

class miniDcmXmlWidget;

class MainWindow : public QMainWindow
{
  Q_OBJECT
public:
  MainWindow(QWidget *parent = 0, Qt::WFlags flags = 0);
  ~MainWindow();
  QClipboard *clipboard;
  
private:
  void checkDcmtkDictionary();
  MiniDcmXmlWidget *miniDcmXmlWidget;
  QPushButton* dirImportPushButton;
  //QPushButton* dirPreviewPushButton;
  QPushButton *pushButtonSaveVolume;
  QFileSystemModel* dir_model;
  QTreeView *dir_tree;
  
  QDicomDirIconWidget *qdicomDirIconWidget;
  QDir currentDcmDir;
  bool one_proven_dcm_file_in_subdirs(QString parent_dir_str);
  bool dcm_in_subdirs(QString parent_dir_str);
  Ui_qdicomimageForm *qdif;
  SaveVolume *dockSaveVolume;
  QLabel *labelSelectImage;
  
  QString dicomPath;
  void readSettings();
  void writeSettings();
  
  QErrorMessage *errorMessage;
  
  void showNoDicomMessage(QString folder, int msgText);
  
  int countFiles(const QString &path, int limit = 0, bool countDirs = false);
  
  
private slots:
  void checkSelectedDir(QModelIndex);
  void importDir();
  void previewDcmSeries();
  void dockSaveVolumeHide();
  void dockSaveVolumeShow();
  void pushButtonSaveVolumeEnable(MinDcmImage *selectedDcmImage);
  void pushButtonSaveVolumeDisable();
  
protected:
  void closeEvent(QCloseEvent *event);
  
};

#endif // MAINWINDOW_H
