/**************************************************************************
 *  Based on Jeroen van der Waal's code (2007)                            *
 *  jwaal@kabelfoon.nl                                                    *
 *                                                                        *
 *  Modifications: Johannes A. Koeppen, koeppen@ieee.org                  *
 *  Year(s)      : 2010 - 2015                                            *
 *  File         : minDcmImage.h                                          *
 *  Context      : Sdr2 (Not approved for clinical use)                   *
 *  License      : GPL 2 or later                                         *
 *  Description  : minimal DICOM image                                    *
 *                                                                        *
 **************************************************************************/


#ifndef MINDCMIMAGE_H
#define MINDCMIMAGE_H

#include <QImage>
#include <QSize>
#include <QPixmap>
#include <QStringList>
#include <QDate>

//debug tst:
#include <dcmtk/config/osconfig.h>
//#include <dcmtk/ofstd/ofstring.h>
//#include <dcmtk/ofstd/ofconsol.h>
#include <dcmtk/dcmdata/dcdeftag.h>
#include <dcmtk/dcmdata/dcfilefo.h>
#include <dcmtk/dcmdata/dcdatset.h>
#include <dcmtk/dcmdata/dcelem.h>
#include <dcmtk/dcmjpeg/djdecode.h>  /* for jpeg decoder */
#include <dcmtk/dcmdata/dcrledrg.h>

#include <dcmtk/dcmjpeg/dipijpeg.h>     /* for dcmimage JPEG plugin */

#include <dcmtk/dcmimgle/digsdfn.h>       /* for DiGSDFunction */
#include <dcmtk/dcmimgle/diciefn.h>       /* for DiCIELABFunction */



#include <dcmtk/ofstd/ofstdinc.h>
#include <dcmtk/dcmdata/dctk.h>          /* for various dcmdata headers */
#include <dcmtk/ofstd/ofstd.h>         /* for OFStandard */
#include <dcmtk/dcmimgle/dcmimage.h>      /* for DicomImage */
#include <dcmtk/dcmimgle/diutils.h>
#include <dcmtk/dcmimgle/didispfn.h>
#include <dcmtk/dcmjpeg/djutils.h>

typedef enum {IMG_DEPTH8 = 8};
typedef enum {IMG_DEPTH12 = 12};


class MinDcmImage
{

public:

  /**
   * Opens a dicom file using the dcmtk toolkit.
   * @param filename the filename of the of the dicom file to open
   * @param flags see documentation dcmtk
   * @param fstart see documentation dcmtk
   * @param fcount see documentation dcmtk
   */
  //! @todo should also be possible to dynamic load in another file.
  //! @todo aspect ratio is not taken into account
  //MinDcmImage(const QString& filename, const unsigned long flags=0,
  //            const unsigned long fstart=0, const unsigned long fcount=0);
  MinDcmImage(const QString& filename, bool getImage);
  //MinDcmImage();
  virtual ~MinDcmImage();
  const QImage& outputData(const unsigned long p_frame = 0,
                           const int p_planar = 0); // const;
                           
                           
  //accession
  //QString m_full_path_and_name;
  QString m_image_absolute_filepath;
  QString m_transfer_syntax_uid; //0002,0010	TransferSyntaxUID
  QString m_sop_instance_uid; //0008, 0018
  QString m_patient_name;
  QString m_pat_birth_date;
  QString m_series_date; //0080 0021
  QString m_series_time; //0080 0031
  QString m_modality; // 0008 0060
  QString m_series_description; //0008 103E
  QString m_study_description; //0008 1030
  
  QString m_device_manufacturer; //0008, 0070
  QString m_manufacturers_model_name; // 0008, 1090: Manufacturer's Model Name: SOMATOM PLUS
  
  QString m_patient_label;
  QString m_study_label;
  QString m_series_label;
  QString m_image_label;
  QString m_slice_thickness; //0018 0050
  
  // split combined MR series:
  float m_mr_echo_time; // 0018,0081
  
  QString m_detector_tilt; // 0018 1120
  //QString m_patient_position; // 0018 5100
  QString m_patient_position; //0018,5100
  QString m_study_instance_uid; //0020, 000D
  QString m_series_instance_uid; //0020, 000E
  QString m_series_number; //0020, 0011
  //QString m_acquisition_number; //0020, 0012
  QString m_instance_number; //0020, 0013
  QString m_image_position_patient_str; //0020 0032
  QString m_images_comments; //0020, 4000
  
  QString m_image_orientation_patient_str; //0020 0037
  QString m_frame_of_reference; //0020 0052
  
  QString m_photometric_interpretation; //0028, 0004
  QString m_img_rows; //0028 0010
  QString m_img_columns; //0028 0011
  QString m_pixel_spacing; //0028 0030
  
  QString m_bits_allocated; //0028 0100
  QString m_bits_stored; //0028 0101
  
  Sint16 m_smallest_image_pixel_value_ss;  //0028, 0106
  Sint16 m_largest_image_pixel_value_ss;  //0028, 0107
  
  QString m_win_center_string; //0028, 1050
  QString m_win_width_string; //0028, 1051
  QString m_rescale_intercept_string; //0028, 1052
  QString m_rescale_slope_string;  //0028, 1053
  QString m_voi_lut_function; // 0028,1056
  
  int m_dcmImageDepth;
  double m_dcmImageWinCenterAndWidth[2];
  unsigned long m_dcmImageFrameCount;
  
  uchar *m_dcm8bitData;
  DcmFileFormat* m_dicomFileFormat;
  DicomImage* m_dicomImage;
  QImage m_qimage;
  QPixmap m_pixmap;
  
  /* will be calculated in 'saveVolume' */
  //For each slice, the normal to the slice orientation is the cross
  //product of the row and column unit vectors (first three and second
  //three values of Image Orientation (Patient), respectively).
  double m_image_position_patient_array[3]; //0020,0032 Image Position Patient
  double m_distance_to_origin;
  double m_dcmImageThickness;
  
  /**
   * Returns if everything is loaded succesfully
   * @return true when file is loaded succesfully
   */
  unsigned long m_previousConvertedFrame;
  bool m_success;
  bool m_renewImage;
  
  const QString& label() const
  {
    return m_image_label;
  };
  const QPixmap& icon() const
  {
    return m_pixmap;
  };
  const QString&file_ID() const
  {
    return m_image_absolute_filepath;
  };
  
  /******* bo to do *******/
  
  //Methods related to windowing of the image
  /**
   * Set the value for the Window Center (brightness)
   * @param center the value to set
   */
  void setWindowCenter(const double center);
  /**
   * Get the value for the Window Center (brightness)
   * @param center the current value
   */
  double windowCenter() const;
  /**
   * Set the value for the Window Width (brightness)
   * @param width the value to set
   */
  void setWindowWidth(const double width);
  /**
   * Get the value for the Window Width (contrast)
   * @param center the current value
   */
  double windowWidth() const;
  /**
   * Use the min max algorithm to set the window width
   * and window center. See dcmtk documentation.
   * @return
   */
  bool setMinMaxWindow();
  /**
   * Get minimum and maximum pixel values.
   * @param min minimum pixel value (reference parameter)
   * @param max maximum pixel value (reference parameter)
   * @return true if successfull
   */
  bool minMaxValues(double& min, double& max) const;
  
  /**
   * Available frames within the current file
   * @return number of available frames
   */
  unsigned long frameCount() const;
  
  /**
   * Tries on several ways to determine the required frame rate.
   * if not succusfull a default of 30 frames/sec is taken.
   * @return
   */
  int frameTimeMsec() const;
  
  /**
   * Size of the image
   * @return size
   * @todo implicit within qimage. Not needed
   */
  QSize size();
  
  /******* eo to do *******/
  
private:
  EI_Status m_status;
  unsigned long p_frame;
  bool loadDicomImg(const char *full_file_name);
  bool getElement(DcmDataset *dataset, DcmTagKey searchKey, QString *element);
  bool getSSElement(DcmDataset *dataset, DcmTagKey searchKey, Sint16 *ss);
  QString dcmDateTodmyString(QString dcmDate);
  QString dcmTimeTohhmmssString(QString long_dcm_time);
  QString firstIntString(QString str);
};

#endif
