/**************************************************************************
 *  Author      : Johannes A. Koeppen, koeppen@ieee.org                   *
 *  Year(s)     : 2010 - 2015                                             *
 *  File        : minDcmXmlTree.h                                         *
 *  Context     : Sdr2 (Not approved for clinical use)                    *
 *  License     : GPL 2 or later                                          *
 *  Description : minimal file tree                                       *
 *                                                                        *
 **************************************************************************/

#ifndef MINIDCMXMLTREE_H
#define MINIDCMXMLTREE_H

#include <QDomDocument>
#include <QHash>
#include <QIcon>
#include <QXmlSimpleReader>
#include <QXmlDefaultHandler>
#include <QXmlParseException>

#include <QTreeWidget>
#include "minDcmImage.h"

enum Found {NothingFound, PatientFound, StudyFound, SeriesFound,
            ImageFound
           };


class MiniDcmXmlTree: public QTreeWidget
{
  Q_OBJECT
  
public:
  MiniDcmXmlTree(QWidget *parent = 0);
  QString xmlDefaultFileName;
  enum Found found;
  void ignoreBadFileOrExit(QFile *badFile);
  bool readXmlDevice(QIODevice *device);
  bool writeXmlDevice(QIODevice *device);
  bool loadDcmImage(const QString &fileName);
  bool reallyWantToAddFolder(QString fullFileName, int column = 0);
  bool insertDcmImage();
  QTreeWidgetItem *selectedItem;
  QDomElement selectedDomElement;
  bool deleteItem();
  bool itemSelected;
  QStringList imageList;
  QHash<QTreeWidgetItem *, QDomElement> domElementForItem;
  
public slots:
  void getSelectedItem(QTreeWidgetItem *item);
  void preparePreview();
  
signals:
  void signalSelectionChanged(QString);
  void signalDcmPreview();
  
  
private slots:
  void updateDomElement(QTreeWidgetItem *item, int column);
  Found findDcmXmlElements(const QDomElement &element, MinDcmImage *midi);
  
private:
  void parseDcmXmlDevice(const QDomElement &element,
                         QTreeWidgetItem *parentItem = 0);
  QTreeWidgetItem *createItem(const QDomElement &element,
                              QTreeWidgetItem *parentItem = 0);
                              
  QDomDocument domDocument;
  MinDcmImage *midi;
  QIcon folderIcon;
  QIcon seriesIcon;
};

#endif
