/**************************************************************************
 *  Author      : Johannes A. Koeppen, koeppen@ieee.org                   *
 *  Year(s)     : 2010 - 2015                                             *
 *  File        : minDcmXmlWidget.h                                       *
 *  Context     : Sdr2 (Not approved for clinical use)                    *
 *  License     : GPL 2 or later                                          *
 *  Description : minimal DICOM Image widget to read and write XML        *
 *                                                                        *
 **************************************************************************/

#ifndef MINIDCMXMLWIDGET_H
#define MINIDCMXMLWIDGET_H

#include <QMainWindow>
#include <QPushButton>
#include <QTreeWidget>

class MiniDcmXmlTree;

class MiniDcmXmlWidget : public QWidget
{
  Q_OBJECT
  
public:
  MiniDcmXmlWidget();
  MiniDcmXmlTree *miniDcmXmlTree;
  
public slots:
  void openXmlDefault();
  void openXmlDcm();
  void saveXmlDcm();
  void saveAndOpenXmlDcm();
  void reloadXmlDcm(QString fileName);
  void about();
  void parseDcmDir(QString dirName);
  void insertDcmDir(QString dirName);
  void deleteXmlItem();
  void updateButtons(QString selected_tag);
  
private slots:
  void doubleClickedHandler(QTreeWidgetItem *item, int column);
  
private:
  int countDcmSuccess;
  void insertDcmFile(QString dcmFileName, bool reload);
  
  QPushButton *pushButtonDelete;
  QPushButton *pushButtonOpenXml;
  QPushButton *pushButtonSaveXml;
  QPushButton *pushButtonPreview;
  QString domFileName;
  QString searchDicomDir;
};

#endif
