/***************************************************************************
 *   Copyright (C) 2007 by Jeroen van der Waal                             *
 *   jwaal@kabelfoon.nl                                                    *
 *                                                                         *
 *   with minor distortions by Johannes A. Koeppen                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef QDICOMIMAGEFORM_H
#define QDICOMIMAGEFORM_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QHBoxLayout>
#include <QtGui/QLCDNumber>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSlider>
#include <QtGui/QSpacerItem>
#include <QtGui/QSplitter>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "./qdicomimagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_qdicomimageForm
{
public:
  QSplitter *splitter_image_form;
  QWidget *layoutWidget;
  QVBoxLayout *outerVBoxLayout;
  QHBoxLayout *layout_windowing_all;
  QSpacerItem *spacer_windowing;
  QHBoxLayout *layout_windowing_contols;
  QVBoxLayout *layout_windowing_labels;
  QLabel *label_width;
  QLabel *label_center;
  QVBoxLayout *layout_windowing;
  QSlider *horizontalSlider_width;
  QSlider *horizontalSlider_center;
  QDicomImageWidget *qdicomImageWidget;
  QHBoxLayout *layout_player_all;
  QSpacerItem *spacer_player;
  QHBoxLayout *layout_player_controls;
  // multiframe QPushButton *pushButton_rewind;
  // multiframe QPushButton *pushButton_pause;
  // multiframe QPushButton *pushButton_play;
  // multiframe QPushButton *pushButton_foreward;
  QHBoxLayout *layout_dcm_frames;
  QSpacerItem *spacer_dcm_frames;
  QHBoxLayout *layout_dcm_frame_controls;
  QVBoxLayout *layout_dcm_current_frame;
  // multiframe QLabel *label_current_frame;
  // multiframe QLCDNumber *lcdNumber_current_frame;
  QVBoxLayout *layout_dcm_frame_fps;
  // multiframe QLabel *label_fps;
  // multiframe QLCDNumber *lcdNumber_fps;
  QVBoxLayout *layout_dcm_frames_control;
  QHBoxLayout *layout_dcm_frame_zoom;
  QLabel *label_dcm_frame_zoom;
  QSlider *horizontalSlider_dcm_frame_zoom;
  // multiframe QHBoxLayout *layout_dcm_frame_speed;
  // multiframe QLabel *label_dcm_frame_speed;
  // multiframe QSlider *horizontalSlider_dcm_frame_speed;
  
  void setupUi(QWidget *qdicomimageForm)
  {
    if (qdicomimageForm->objectName().isEmpty())
      qdicomimageForm->setObjectName(QString::fromUtf8("qdicomimageForm"));
    qdicomimageForm->resize(448, 405);
    splitter_image_form = new QSplitter(qdicomimageForm);
    splitter_image_form->setObjectName(QString::fromUtf8("splitter_image_form"));
    splitter_image_form->setGeometry(QRect(0, 0, 431, 392));
    QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
    sizePolicy.setHorizontalStretch(0);
    sizePolicy.setVerticalStretch(0);
    sizePolicy.setHeightForWidth(splitter_image_form->sizePolicy().hasHeightForWidth());
    splitter_image_form->setSizePolicy(sizePolicy);
    splitter_image_form->setMinimumSize(QSize(0, 0));
    splitter_image_form->setOrientation(Qt::Horizontal);
    layoutWidget = new QWidget(splitter_image_form);
    layoutWidget->setObjectName(QString::fromUtf8("layoutWidget"));
    outerVBoxLayout = new QVBoxLayout(layoutWidget);
#ifndef Q_OS_MAC
    outerVBoxLayout->setSpacing(6);
#endif
    outerVBoxLayout->setMargin(6);
    outerVBoxLayout->setObjectName(QString::fromUtf8("outerVBoxLayout"));
    outerVBoxLayout->setContentsMargins(0, 0, 0, 0);
    layout_windowing_all = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_windowing_all->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_windowing_all->setMargin(0);
#endif
    layout_windowing_all->setObjectName(QString::fromUtf8("layout_windowing_all"));
    spacer_windowing = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
    
    layout_windowing_all->addItem(spacer_windowing);
    
    layout_windowing_contols = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_windowing_contols->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_windowing_contols->setMargin(0);
#endif
    layout_windowing_contols->setObjectName(QString::fromUtf8("layout_windowing_contols"));
    layout_windowing_labels = new QVBoxLayout();
#ifndef Q_OS_MAC
    layout_windowing_labels->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_windowing_labels->setMargin(0);
#endif
    layout_windowing_labels->setObjectName(QString::fromUtf8("layout_windowing_labels"));
    label_width = new QLabel(layoutWidget);
    label_width->setObjectName(QString::fromUtf8("label_width"));
    
    layout_windowing_labels->addWidget(label_width);
    
    label_center = new QLabel(layoutWidget);
    label_center->setObjectName(QString::fromUtf8("label_center"));
    
    layout_windowing_labels->addWidget(label_center);
    
    
    layout_windowing_contols->addLayout(layout_windowing_labels);
    
    layout_windowing = new QVBoxLayout();
#ifndef Q_OS_MAC
    layout_windowing->setSpacing(6);
#endif
    layout_windowing->setMargin(0);
    layout_windowing->setObjectName(QString::fromUtf8("layout_windowing"));
    horizontalSlider_width = new QSlider(layoutWidget);
    horizontalSlider_width->setObjectName(QString::fromUtf8("horizontalSlider_width"));
    horizontalSlider_width->setMinimum(-100);
    horizontalSlider_width->setMaximum(100);
    horizontalSlider_width->setPageStep(1);
    horizontalSlider_width->setSingleStep(0.5);
    horizontalSlider_width->setOrientation(Qt::Horizontal);
    
    layout_windowing->addWidget(horizontalSlider_width);
    
    horizontalSlider_center = new QSlider(layoutWidget);
    horizontalSlider_center->setObjectName(QString::fromUtf8("horizontalSlider_center"));
    horizontalSlider_center->setMinimum(-100);
    horizontalSlider_center->setMaximum(100);
    horizontalSlider_center->setPageStep(1);
    horizontalSlider_center->setSingleStep(0.5);
    
    horizontalSlider_center->setOrientation(Qt::Horizontal);
    layout_windowing->addWidget(horizontalSlider_center);
    layout_windowing_contols->addLayout(layout_windowing);
    layout_windowing_all->addLayout(layout_windowing_contols);
    outerVBoxLayout->addLayout(layout_windowing_all);
    qdicomImageWidget = new QDicomImageWidget(layoutWidget);
    qdicomImageWidget->setObjectName(QString::fromUtf8("qdicomImageWidget"));
    qdicomImageWidget->setProperty("AutoZoomAtResize", QVariant(false));
    outerVBoxLayout->addWidget(qdicomImageWidget);
    layout_player_all = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_player_all->setSpacing(6);
#endif
    layout_player_all->setMargin(0);
    layout_player_all->setObjectName(QString::fromUtf8("layout_player_all"));
    spacer_player = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
    layout_player_all->addItem(spacer_player);
    layout_player_controls = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_player_controls->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_player_controls->setMargin(0);
#endif
    layout_player_controls->setObjectName(QString::fromUtf8("layout_player_controls"));
// multiframe     pushButton_rewind = new QPushButton(layoutWidget);
// multiframe     pushButton_rewind->setObjectName(QString::fromUtf8("pushButton_rewind"));
// multiframe     pushButton_rewind->setEnabled(false);
// multiframe     QIcon icon;
// multiframe     icon.addPixmap(QPixmap(QString::fromUtf8("../../images/player_start.png")), QIcon::Normal, QIcon::Off);
// multiframe     pushButton_rewind->setIcon(icon);

// multiframe     layout_player_controls->addWidget(pushButton_rewind);

// multiframe     pushButton_pause = new QPushButton(layoutWidget);
// multiframe     pushButton_pause->setObjectName(QString::fromUtf8("pushButton_pause"));
// multiframe     pushButton_pause->setEnabled(false);
// multiframe     QIcon icon1;
// multiframe     icon1.addPixmap(QPixmap(QString::fromUtf8("../../images/player_stop.png")), QIcon::Normal, QIcon::Off);
// multiframe     pushButton_pause->setIcon(icon1);

// multiframe     layout_player_controls->addWidget(pushButton_pause);

// multiframe     pushButton_play = new QPushButton(layoutWidget);
// multiframe     pushButton_play->setObjectName(QString::fromUtf8("pushButton_play"));
// multiframe     pushButton_play->setEnabled(false);
// multiframe     QIcon icon2;
// multiframe    icon2.addPixmap(QPixmap(QString::fromUtf8("../../images/player_play.png")), QIcon::Normal, QIcon::Off);
// multiframe     pushButton_play->setIcon(icon2);

// multiframe     layout_player_controls->addWidget(pushButton_play);

// multiframe     pushButton_foreward = new QPushButton(layoutWidget);
// multiframe     pushButton_foreward->setObjectName(QString::fromUtf8("pushButton_foreward"));
// multiframe     pushButton_foreward->setEnabled(false);
// multiframe     QIcon icon3;
// multiframe     icon3.addPixmap(QPixmap(QString::fromUtf8("../../images/player_end.png")), QIcon::Normal, QIcon::Off);
// multiframe     pushButton_foreward->setIcon(icon3);

// multiframe     layout_player_controls->addWidget(pushButton_foreward);

    layout_player_all->addLayout(layout_player_controls);
    
    outerVBoxLayout->addLayout(layout_player_all);
    
    layout_dcm_frames = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_frames->setSpacing(6);
#endif
    layout_dcm_frames->setMargin(0);
    layout_dcm_frames->setObjectName(QString::fromUtf8("layout_dcm_frames"));
    spacer_dcm_frames = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);
    
    layout_dcm_frames->addItem(spacer_dcm_frames);
    
    layout_dcm_frame_controls = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_frame_controls->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_dcm_frame_controls->setMargin(0);
#endif
    layout_dcm_frame_controls->setObjectName(QString::fromUtf8("layout_dcm_frame_controls"));
    layout_dcm_current_frame = new QVBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_current_frame->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_dcm_current_frame->setMargin(0);
#endif
    layout_dcm_current_frame->setObjectName(QString::fromUtf8("layout_dcm_current_frame"));
// multiframe     label_current_frame = new QLabel(layoutWidget);
// multiframe     label_current_frame->setObjectName(QString::fromUtf8("label_current_frame"));
// multiframe     layout_dcm_current_frame->addWidget(label_current_frame);
// multiframe     lcdNumber_current_frame = new QLCDNumber(layoutWidget);
// multiframe     lcdNumber_current_frame->setObjectName(QString::fromUtf8("lcdNumber_current_frame"));
// multiframe     layout_dcm_current_frame->addWidget(lcdNumber_current_frame);

    layout_dcm_frame_controls->addLayout(layout_dcm_current_frame);
    layout_dcm_frame_fps = new QVBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_frame_fps->setSpacing(6);
#endif
    layout_dcm_frame_fps->setMargin(0);
    layout_dcm_frame_fps->setObjectName(QString::fromUtf8("layout_dcm_frame_fps"));
// multiframe     label_fps = new QLabel(layoutWidget);
// multiframe     label_fps->setObjectName(QString::fromUtf8("label_fps"));
// multiframe     layout_dcm_frame_fps->addWidget(label_fps);
// multiframe     lcdNumber_fps = new QLCDNumber(layoutWidget);
// multiframe     lcdNumber_fps->setObjectName(QString::fromUtf8("lcdNumber_fps"));
// multiframe     layout_dcm_frame_fps->addWidget(lcdNumber_fps);

    layout_dcm_frame_controls->addLayout(layout_dcm_frame_fps);
    
    layout_dcm_frames_control = new QVBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_frames_control->setSpacing(6);
#endif
    layout_dcm_frames_control->setMargin(0);
    layout_dcm_frames_control->setObjectName(QString::fromUtf8("layout_dcm_frames_control"));
    layout_dcm_frame_zoom = new QHBoxLayout();
#ifndef Q_OS_MAC
    layout_dcm_frame_zoom->setSpacing(6);
#endif
#ifndef Q_OS_MAC
    layout_dcm_frame_zoom->setMargin(0);
#endif
    layout_dcm_frame_zoom->setObjectName(QString::fromUtf8("layout_dcm_frame_zoom"));
    label_dcm_frame_zoom = new QLabel(layoutWidget);
    label_dcm_frame_zoom->setObjectName(QString::fromUtf8("label_dcm_frame_zoom"));
    
    layout_dcm_frame_zoom->addWidget(label_dcm_frame_zoom);
    
    horizontalSlider_dcm_frame_zoom = new QSlider(layoutWidget);
    horizontalSlider_dcm_frame_zoom->setMinimumWidth(80);
    horizontalSlider_dcm_frame_zoom->setObjectName(
      QString::fromUtf8("horizontalSlider_dcm_frame_zoom"));
    horizontalSlider_dcm_frame_zoom->setMinimum(30);
    horizontalSlider_dcm_frame_zoom->setMaximum(400); //200);
    horizontalSlider_dcm_frame_zoom->setSingleStep(10);
    horizontalSlider_dcm_frame_zoom->setValue(100);
    horizontalSlider_dcm_frame_zoom->setOrientation(Qt::Horizontal);
    
    layout_dcm_frame_zoom->addWidget(horizontalSlider_dcm_frame_zoom);
    layout_dcm_frames_control->addLayout(layout_dcm_frame_zoom);
    
// multiframe     layout_dcm_frame_speed = new QHBoxLayout();
#ifndef Q_OS_MAC
// multiframe     layout_dcm_frame_speed->setSpacing(6);
#endif
// multiframe     layout_dcm_frame_speed->setMargin(0);
// multiframe     layout_dcm_frame_speed->setObjectName(QString::fromUtf8("layout_dcm_frame_speed"));
// multiframe     label_dcm_frame_speed = new QLabel(layoutWidget);
// multiframe     label_dcm_frame_speed->setObjectName(QString::fromUtf8("label_dcm_frame_speed"));
// multiframe     layout_dcm_frame_speed->addWidget(label_dcm_frame_speed);
// multiframe     horizontalSlider_dcm_frame_speed = new QSlider(layoutWidget);
// multiframe     horizontalSlider_dcm_frame_speed->setObjectName(QString::fromUtf8("horizontalSlider_dcm_frame_speed"));
// multiframe     horizontalSlider_dcm_frame_speed->setEnabled(false);
// multiframe     horizontalSlider_dcm_frame_speed->setMinimum(30);
// multiframe     horizontalSlider_dcm_frame_speed->setMaximum(200);
// multiframe     horizontalSlider_dcm_frame_speed->setSingleStep(10);
// multiframe     horizontalSlider_dcm_frame_speed->setValue(100);
// multiframe     horizontalSlider_dcm_frame_speed->setOrientation(Qt::Horizontal);
// multiframe     layout_dcm_frame_speed->addWidget(horizontalSlider_dcm_frame_speed);
// multiframe     layout_dcm_frames_control->addLayout(layout_dcm_frame_speed);

    layout_dcm_frame_controls->addLayout(layout_dcm_frames_control);
    layout_dcm_frames->addLayout(layout_dcm_frame_controls);
    outerVBoxLayout->addLayout(layout_dcm_frames);
    splitter_image_form->addWidget(layoutWidget);
    retranslateUi(qdicomimageForm);
    
    //QMetaObject::connectSlotsByName(qdicomimageForm);
    QObject::connect(horizontalSlider_dcm_frame_zoom, SIGNAL(valueChanged(int)), qdicomImageWidget,
                     SLOT(setZoomFactor(int)));
    //horizontalSlider_3: slider_width   horizontalSlider_width
    //horizontalSlider_4: slider_center   horizontalSlider_center
    //pushButton_5 rewind  pushButton_rewind
    //pushButton_2 stop  pushButton_pause
    //pushButton play  pushButton_play
    //pushButton_4 foreward  pushButton_foreward
    //lcdNumber current_frame  lcdNumber_current_frame
    //lcdNumber_2 fps  lcdNumber_fps
    //horizontalSlider zoom  horizontalSlider_dcm_frame_zoom
    //horizontalSlider_2 speed horizontalSlider_dcm_frame_speed
    
    //QObject::connect(dicomDirList, SIGNAL(newFileLoaded(QString)), qdicomDirIconWidget, SLOT(loadFile(QString)));
    //QObject::connect(dicomDirList, SIGNAL(imageSelected(QString)), qdicomImageWidget, SLOT(loadFile(QString)));
    //QObject::connect(dicomDirList, SIGNAL(referenceFileIDSelected(QString)), qdicomDirIconWidget, SLOT(selectedReferenceFileID(QString)));
// multiframe     QObject::connect(pushButton_pause, SIGNAL(clicked()),
// multiframe       qdicomImageWidget, SLOT(stop()));
// multiframe     QObject::connect(pushButton_play, SIGNAL(clicked()),
// multiframe       qdicomImageWidget, SLOT(play()));
// multiframe     QObject::connect(pushButton_rewind, SIGNAL(clicked()),
// multiframe       qdicomImageWidget, SLOT(previousFrame()));
// multiframe     QObject::connect(pushButton_foreward, SIGNAL(clicked()),
// multiframe       qdicomImageWidget, SLOT(nextFrame()));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(currentFrame(int)),
// multiframe       lcdNumber_current_frame, SLOT(display(int)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(averageFrameRate(int)),
// multiframe       lcdNumber_fps, SLOT(display(int)));
    QObject::connect(horizontalSlider_dcm_frame_zoom, SIGNAL(valueChanged(int)),
                     qdicomImageWidget, SLOT(setZoomFactor(int)));
// multiframe     QObject::connect(horizontalSlider_dcm_frame_speed, SIGNAL(valueChanged(int)),
// multiframe       qdicomImageWidget, SLOT(setSpeed(int)));
    QObject::connect(qdicomImageWidget, SIGNAL(zoomValueChanged(int)),
                     horizontalSlider_dcm_frame_zoom, SLOT(setValue(int)));
    QObject::connect(horizontalSlider_width, SIGNAL(valueChanged(int)),
                     qdicomImageWidget, SLOT(setCurrentImageWindowWidth(int)));
    QObject::connect(horizontalSlider_center, SIGNAL(valueChanged(int)),
                     qdicomImageWidget, SLOT(setCurrentImageWindowCenter(int)));
                     
    QObject::connect(horizontalSlider_width, SIGNAL(sliderReleased()),
                     qdicomImageWidget, SLOT(imageWidthOrCenterReleased()));
    QObject::connect(horizontalSlider_center, SIGNAL(sliderReleased()),
                     qdicomImageWidget, SLOT(imageWidthOrCenterReleased()));
    //QObject::connect(qdicomDirIconWidget, SIGNAL(imageSelected(QString)),
    //  qdicomImageWidget, SLOT(loadFile(QString)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(multiframe(bool)),
// multiframe       pushButton_rewind, SLOT(setEnabled(bool)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(multiframe(bool)),
// multiframe       pushButton_pause, SLOT(setEnabled(bool)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(multiframe(bool)),
// multiframe       pushButton_play, SLOT(setEnabled(bool)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(multiframe(bool)),
// multiframe       pushButton_foreward, SLOT(setEnabled(bool)));
// multiframe     QObject::connect(qdicomImageWidget, SIGNAL(multiframe(bool)),
// multiframe       horizontalSlider_dcm_frame_speed, SLOT(setEnabled(bool)));
  } // setupUi
  
  void retranslateUi(QWidget *qdicomimageForm)
  {
    qdicomimageForm->setWindowTitle(QApplication::translate("qdicomimageForm", "Form", 0,
                                    QApplication::UnicodeUTF8));
    label_width->setText(QApplication::translate("qdicomimageForm", "Width", 0,
                         QApplication::UnicodeUTF8));
    label_center->setText(QApplication::translate("qdicomimageForm", "Center", 0,
                          QApplication::UnicodeUTF8));
                          
#ifndef QT_NO_TOOLTIP
    horizontalSlider_width->setToolTip(QApplication::translate("qdicomimageForm",
                                       "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                       "p, li { white-space: pre-wrap; }\n"
                                       "</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
                                       "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Contrast. Only works for gray level images.</p></body></html>",
                                       0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
                                       
                                       
#ifndef QT_NO_TOOLTIP
    horizontalSlider_center->setToolTip(QApplication::translate("qdicomimageForm",
                                        "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
                                        "p, li { white-space: pre-wrap; }\n"
                                        "</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
                                        "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Brightness. Only works for gray level images.</p></body></html>",
                                        0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
                                        
                                        
#ifndef QT_NO_TOOLTIP
    qdicomImageWidget->setToolTip(QApplication::translate("qdicomimageForm",
                                  "Displays DICOM images, loops and runs.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
                                  
                                  
#ifndef QT_NO_WHATSTHIS
    qdicomImageWidget->setWhatsThis(QApplication::translate("qdicomimageForm",
                                    "A widget to display DICOM images, loops and runs.", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_WHATSTHIS
                                    
// multiframe     pushButton_rewind->setText(QString());
// multiframe     pushButton_pause->setText(QString());
// multiframe     pushButton_play->setText(QString());
// multiframe     pushButton_foreward->setText(QString());
// multiframe     label_current_frame->setText(QApplication::translate("qdicomimageForm", "Current Frame", 0, QApplication::UnicodeUTF8));
// multiframe     label_fps->setText(QApplication::translate("qdicomimageForm", "FPS", 0, QApplication::UnicodeUTF8));

    /* multiframe
    #ifndef QT_NO_TOOLTIP
        lcdNumber_fps->setToolTip(QApplication::translate("qdicomimageForm", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
          "p, li { white-space: pre-wrap; }\n"
          "</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
          "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Frames per second</p></body></html>", 0, QApplication::UnicodeUTF8));
    #endif // QT_NO_TOOLTIP
    multiframe */
    
    label_dcm_frame_zoom->setText(QApplication::translate("qdicomimageForm", "Zoom", 0,
                                  QApplication::UnicodeUTF8));
                                  
#ifndef QT_NO_TOOLTIP
    horizontalSlider_dcm_frame_zoom->setToolTip(QApplication::translate("qdicomimageForm",
        "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
        "p, li { white-space: pre-wrap; }\n"
        "</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
        "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Zoom factor between 30-200%</p></body></html>",
        0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        
// multiframe     label_dcm_frame_speed->setText(QApplication::translate("qdicomimageForm", "Speed", 0, QApplication::UnicodeUTF8));
    /* multiframe
    #ifndef QT_NO_TOOLTIP
        horizontalSlider_dcm_frame_speed->setToolTip(QApplication::translate("qdicomimageForm", "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
          "p, li { white-space: pre-wrap; }\n"
          "</style></head><body style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;\">\n"
          "<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Zoom factor between 30-200%</p></body></html>", 0, QApplication::UnicodeUTF8));
    #endif // QT_NO_TOOLTIP
    multiframe */
    
    Q_UNUSED(qdicomimageForm);
  } // retranslateUi
  
};

namespace Ui
{
class qdicomimageForm: public Ui_qdicomimageForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QDICOMIMAGEFORM
