/***************************************************************************
 *   Copyright (C) 2006 by Jeroen van der Waal   *
 *   jwaal@kabelfoon.nl   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "qdicomimagewidgetplugin.h"
#include "qdicomimagewidget.h"

#include <QtPlugin>

/*!
    \class QPluginDicomImageWidget
    \brief Makes DicomImageWidget into a designer plugin.
*/

QPluginDicomImageWidget::QPluginDicomImageWidget(QObject *parent)
  : QObject(parent)
  , m_initialized(false)
{

  //empty
}

bool QPluginDicomImageWidget::isInitialized( ) const
{
  return m_initialized;
}

void QPluginDicomImageWidget::initialize(QDesignerFormEditorInterface*)
{
  if (m_initialized)
    return;
    
  m_initialized = true;
}

bool QPluginDicomImageWidget::isContainer( ) const
{
  return false;
}

QWidget * QPluginDicomImageWidget::createWidget( QWidget * parent )
{
  return new QDicomImageWidget(parent);
}

QString QPluginDicomImageWidget::name( ) const
{
  return "QDicomImageWidget";
}

QString QPluginDicomImageWidget::toolTip( ) const
{
  return "Displays DICOM images, loops and runs.";
}

QString QPluginDicomImageWidget::group( ) const
{
  return "Custom DICOM widgets";
}

QIcon QPluginDicomImageWidget::icon( ) const
{
  return QIcon();
}

QString QPluginDicomImageWidget::whatsThis( ) const
{
  return "A widget to display DICOM images, loops and runs.";
}

QString QPluginDicomImageWidget::includeFile( ) const
{
  return "qdicomimagewidget.h";
}

QString QPluginDicomImageWidget::domXml( ) const
{
  return "<widget class=\"QDicomImageWidget\" name=\"qdicomImageWidget\">\n"
         " <property name=\"geometry\">\n"
         "  <rect>\n"
         "   <x>0</x>\n"
         "   <y>0</y>\n"
         "   <width>200</width>\n"
         "   <height>200</height>\n"
         "  </rect>\n"
         " </property>\n"
         " <property name=\"toolTip\" >\n"
         "  <string>Displays DICOM images, loops and runs.</string>\n"
         " </property>\n"
         " <property name=\"whatsThis\" >\n"
         "  <string>A widget to display DICOM images, loops and runs.</string>\n"
         " </property>\n"
         "</widget>\n";
}
Q_EXPORT_PLUGIN2(qdicomimagewidget, QPluginDicomImageWidget)


