/**************************************************************************
 *  Author      : Johannes A. Koeppen, koeppen@ieee.org                   *
 *  Year(s)     : 2010 - 2015                                             *
 *  File        : saveVolume.h                                            *
 *  Context     : Sdr2 (Not approved for clinical use)                    *
 *  License     : GPL 2 or later                                          *
 *  Description : save DICOM series as Nifti- or Analyze file             *
 *                                                                        *
 **************************************************************************/

#ifndef SAVEVOLUME_H
#define SAVEVOLUME_H

#include <QtGui/QDockWidget>
#include <QVector>

#include "./nifti/nifti1_io.h"

#include "macros.h"
#include "ui_saveOptions.h"
#include "minDcmImage.h"
#include "dcmIconListModel.h"


typedef QVector<MinDcmImage*> TMinDcmImageVector;

class SaveVolume : public QDockWidget, private Ui::DockWidgetSaveOptions
{
  Q_OBJECT
  
public:
  SaveVolume(QWidget *parent = 0);
  ~SaveVolume();
  void setReferenceDcmImage(MinDcmImage *selectedDcmImage);
  void setOrigDcmImageVector(TMinDcmImageVector *dcmImageVector);
  bool sorted;
  
private:
  void setFittingDcmImageVector(TMinDcmImageVector *dcmImageVector);
  QString getMajorAxisFromPatientRelativeDirectionCosine(double x, double y, double z);
  QString makeImageOrientationLabelFromImageOrientationPatient(
    double rowX, double rowY, double rowZ,
    double colX, double colY, double colZ);
  QString calculatePatientOrientation(double x, double y, double z);
  void bubbleSortFittingDcmImageVector();
  int diPixelRepresentationToNiftiDatatype(int rep, bool print);
  bool saveNiftiDcmInternalData();
  void findNiftiQuaternion(nifti_image *hdr);
  void findFullNiftiTransformation(nifti_image *hdr);
  
  mat44 mat44_transpose(mat44 in);
  mat44 mat44_mul(mat44 A , mat44 B);
  void addExtensions(nifti_image *nim);
  MinDcmImage *m_referenceDcmImage;
  TMinDcmImageVector *m_origDcmImageVector;
  TMinDcmImageVector m_fittingDcmImageVector;
  bool success;
  int m_dcmImageHeightInt;
  int m_dcmImageWidthInt;
  
  int m_numNiftiSlices;
  float m_ref_mr_echo_time;
  int m_minInstanceNum;
  int m_maxInstanceNum;
  
  double m_pixel_spacing[3];
  double m_avrg_dcmImageThickness;
  double m_first_image_orientation_patient_array[6];
  double m_first_image_position_patient_array[3]; //0020,0032 Image Position Patient
  bool m_have_image_orientation_patient_array;
  bool m_have_image_position_patient_array;
  
  double obliquityThresholdCosineValue; //= 0.8;
  QString m_dcmImageOrientationLabel;
  QString m_filename, m_filedir;
  QString m_patient_position;
  float fix_rot_row_1[3];
  float fix_rot_row_2[3];
  float fix_rot_row_3[3];
  
private slots:
  void slot_cancel();
  void slot_sort(); //int start_at, int stop_at = 0);
  bool slotFileSave();
  bool slotFileSaveAs();
  
};
#endif //SAVEVOLUME_H
